# System: Aerobee 350
# Program to generate a plot of velocity vs. time
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Define constants
T = 217000.0            # Thrust (N)
m = 3839.0              # Total weight (kg)
g = 9.8                 # Gravity accelation (m/s2)
B = T/m - g             # Expression for B (auxiliary constant)
rho = 1.204             # Air density (kg/m3)
d = 0.56                # Core diameter (m)
A = np.pi*(d/2)**2      # Section area (m2)
CD = 0.4                # Drag coefficient
C = 0.5*rho*CD*A/m      # Expression for C (auxiliary constant)

# Time points
t = np.linspace(0,50.0,1000)

# Define function
v_l = np.sqrt(B/C)
v = v_l*np.tanh(np.sqrt(B*C)*t)
v_defined_time = str(v_l*np.tanh(np.sqrt(B*C)*2.5))

# Define plot parameters
title_in = "Aerobee 350 Rocket\n"
title_in += "Thrust: "+str(T/1000)+" kN, Total weight: "+str(m)+" Kg, "
title_in += "v(2.5s): "+v_defined_time[:5]+" m/s"
x_label_in = "t(s)"
y_label_in = "v(m/s)"
fontsize_title_in = 14
fontsize_x_label_in = 14
fontsize_y_label_in = 14
color_in = "blue"

# Plotting
plt.plot(t, v, c = color_in)
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig("Aerobee_350.png",dpi=900)