# System: Aerobee series
# Program to generate a plot of velocity vs. time
#
# Import section
import numpy as np
import matplotlib.pyplot as plt

# Define constants
g = 9.8                 # Gravity accelation (m/s2)
rho = 1.204             # Air density (kg/m3)
CD = 0.4                # Drag coefficient

# Time points
t = np.linspace(0,50.0,1000)

# Define plot parameters
title_in = "Aerobee Series"
x_label_in = "t(s)"
y_label_in = "v(m/s)"
fontsize_title_in = 14
fontsize_x_label_in = 14
fontsize_y_label_in = 14
color_in = "blue"

# Define lists of data
# Sources:  https://en.wikipedia.org/wiki/Aerobee
#           https://www.designation-systems.net/dusrm/n-2.html
#           https://web.archive.org/web/20160820134110/http://www.astronautix.com/a/aerobee.html
Versions = ["Aerobee RTV-N-8","Aerobee Hi","Aerobee 75","Aerobee 100",
            "Aerobee 150","Aerobee 150A","Aerobee 170","Aerobee 170A",
            "Aerobee 200","Aerobee 300"]
T = [11.5,11.7,7.0,17.8,18.0,18.0,225.0,217.0,225.0,18.0]   # Thrust (N)
m = [745.0,930.0,400.0,770.0,930.0,900.0,1270.0,1270.0,
                                            1600.0,983.0]   # Total weight (kg)
d = [0.38,0.38,0.35,0.38,0.38,0.38,0.42,0.42,0.42,0.38]     # Core diameter (m)


# Looping through data
for i in range(len(T)):

    # Calculate constants
    B = T[i]*1000.0/m[i] - g        # Expression for B (auxiliary constant)
    A = np.pi*(d[i]/2)**2           # Section area (m2)
    C = 0.5*rho*CD*A/m[i]           # Expression for C (auxiliary constant)

    # Define function
    v_l = np.sqrt(B/C)
    v = v_l*np.tanh(np.sqrt(B*C)*t)
    v_defined_time = str(v_l*np.tanh(np.sqrt(B*C)*2.5))
    print("v(2.5 s): ",v_defined_time)
    plt.plot(t, v)

# Plotting
plt.title(title_in, fontsize = fontsize_title_in)
plt.xlabel(x_label_in,fontsize = fontsize_x_label_in)
plt.ylabel(y_label_in,fontsize = fontsize_y_label_in)
plt.grid()
plt.show()
plt.savefig("Aerobee_series.png",dpi=600)